# OPS01-BP06: Evaluate tradeoffs

## Description

Cân nhắc trade-offs khi quản lý benefits và risks.

## Implementation Guidance

- Document trade-off decisions and rationale
- Use decision frameworks (cost-benefit analysis)
- Consider short-term vs long-term impacts
- Involve relevant stakeholders in trade-off discussions
- Regular review of past trade-off decisions

## Risk Level

Medium - Poor trade-off decisions can lead to technical debt.

## Related Best Practices

- [OPS01-BP01](OPS01-BP01-Evaluate-External-Customer-Needs.md)
- [COST03-BP01](../../05-COST/COST03-Resources-Cost-Effective/COST03-BP01-Develop-Cost-Awareness.md)
